@@ -117,7 +117,11 @@ class TestConvertCommand:
         options = self.help_check(options, "-h, --help")
         options = self.help_check(options, "--manpage")
         options = self.help_check(options, "--errorlevel=ERRORLEVEL")
-        options = self.help_check(options, "--psyco=MODE")
+        try:
+            import psyco
+            options = self.help_check(options, "--psyco=MODE")
+        except Exception:
+            pass
         options = self.help_check(options, "-i INPUT, --input=INPUT")
         options = self.help_check(options, "-x EXCLUDE, --exclude=EXCLUDE")
         options = self.help_check(options, "-o OUTPUT, --output=OUTPUT")
