@@ -270,7 +270,8 @@ msgstr "Sertifikate"
         
     def test_merging_obsoleting_messages(self):
         """check that we obsolete messages no longer present in the new file"""
-        potsource = ''
+        #add emtpy msgid line to help factory identify format
+        potsource = 'msgid ""\nmsgstr ""\n'
         posource = '# Some comment\n#. Extracted comment\n#: obsoleteme:10\nmsgid "One"\nmsgstr "Een"\n'
         expected = '# Some comment\n#~ msgid "One"\n#~ msgstr "Een"\n'
         newpo = self.convertpot(potsource, posource)
@@ -280,7 +281,8 @@ msgstr "Sertifikate"
 
     def test_not_obsoleting_empty_messages(self):
         """check that we don't obsolete (and keep) untranslated messages"""
-        potsource = ''
+        #add emtpy msgid line to help factory identify format
+        potsource = 'msgid ""\nmsgstr ""\n'
         posource = '#: obsoleteme:10\nmsgid "One"\nmsgstr ""\n'
         newpo = self.convertpot(potsource, posource)
         print str(newpo)
@@ -411,6 +413,34 @@ msgstr ""
         assert newpounit.isfuzzy()
         assert newpounit.hastypecomment("c-format")
 
+    def test_obsolete_msgctxt(self):
+        """Test that obsolete units' msgctxt is preserved."""
+        potsource = 'msgctxt "newContext"\nmsgid "First unit"\nmsgstr ""'
+        posource = """
+msgctxt "newContext"
+msgid "First unit"
+msgstr "Eerste eenheid"
+
+#~ msgctxt "context"
+#~ msgid "Old unit"
+#~ msgstr "Ou eenheid1"
+
+#~ msgctxt "context2"
+#~ msgid "Old unit"
+#~ msgstr "Ou eenheid2"
+
+#~ msgid "Old unit"
+#~ msgstr "Ou eenheid3"
+"""
+        newpo = self.convertpot(potsource, posource)
+        print newpo
+        assert len(newpo.units) == 5
+        assert newpo.units[1].getcontext() == 'newContext'
+        # Search in unit string, because obsolete units can't return a context
+        assert 'msgctxt "context"' in str(newpo.units[2])
+        assert 'msgctxt "context2"' in str(newpo.units[3])
+
+
 class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
     """Tests running actual pot2po commands on files"""
     convertmodule = pot2po
