@@ -4,7 +4,7 @@ from translate.lang import data
 from translate.storage import po 
 
 def strprep(str1, str2, message=None):
-    return data.forceunicode(str1), data.forceunicode(str2), data.forceunicode(message)
+    return data.normalized_unicode(str1), data.normalized_unicode(str2), data.normalized_unicode(message)
 
 def passes(filterfunction, str1, str2):
     """returns whether the given strings pass on the given test, handling FilterFailures"""
@@ -597,6 +597,10 @@ def test_startpunc():
     assert fails(stdchecker.startpunc, " << Previous", "Wrong")
     assert fails(stdchecker.startpunc, "Question", u"\u2026Wrong")
 
+    # The inverted Spanish question mark should be accepted
+    stdchecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage='es'))
+    assert passes(stdchecker.startpunc, "Do you want to reload the file?", u"¿Quiere recargar el archivo?")
+
 def test_startwhitespace():
     """tests startwhitespace"""
     stdchecker = checks.StandardChecker()
