@@ -35,7 +35,8 @@ class ar(common.Common):
         u",": u"،",
         u";": u"؛",
         u"?": u"؟",
-        u"%": u"٪",
+        #This causes problems with variables, so commented out for now:
+        #u"%": u"٪",
     }
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = ["startcaps", "simplecaps", "acronyms"]
