@@ -87,15 +87,15 @@ class Common(object):
     
     0 is not a valid value - it must be overridden.
     Any positive integer is valid (it should probably be between 1 and 6)
-    Also see data.py
+    @see: L{data}
     """
     
     pluralequation = "0"
     """The plural equation for selection of plural forms. 
 
     This is used for PO files to fill into the header.
-    See U{http://www.gnu.org/software/gettext/manual/html_node/gettext_150.html}.
-    Also see data.py
+    @see: U{Gettext manual<http://www.gnu.org/software/gettext/manual/html_node/gettext_150.html#Plural-forms>}
+    @see: L{data}
     """
     # Don't change these defaults of nplurals or pluralequation willy-nilly:
     # some code probably depends on these for unrecognised languages
@@ -217,11 +217,48 @@ class Common(object):
         # replaced, but the space won't exist at the end of a message.
         # As a simple improvement for messages ending in ellipses (...), we
         # test that the last character is different from the second last
-        if (text[-1] + " " in cls.puncdict) and (text[-2] != text[-1]):
-            text = text[:-1] + cls.puncdict[text[-1] + " "]
+        if (text[-1] + u" " in cls.puncdict) and (text[-2] != text[-1]):
+            text = text[:-1] + cls.puncdict[text[-1] + u" "].rstrip()
         return text
     punctranslate = classmethod(punctranslate)
 
+    def length_difference(cls, len):
+        """Returns an estimate to a likely change in length relative to an
+        English string of length len."""
+        # This is just a rudimentary heuristic guessing that most translations
+        # will be somewhat longer than the source language
+        expansion_factor = 0
+        code = cls.code
+        while code:
+            expansion_factor = data.expansion_factors.get(cls.code, 0)
+            if expansion_factor:
+                break
+            code = data.simplercode(code)
+        else:
+            expansion_factor = 0.1 # default
+        constant = max(5, int(40*expansion_factor))
+        # The default: return 5 + len/10
+        return constant + int(expansion_factor * len)
+
+    def alter_length(cls, text):
+        """Converts the given string by adding or removing characters as an 
+        estimation of translation length (with English assumed as source 
+        language)."""
+        def alter_it(text):
+            l = len(text)
+            if l > 9:
+                extra = cls.length_difference(l)
+                if extra > 0:
+                    text = text[:extra].replace(u'\n', u'') + text
+                else:
+                    text = text[-extra:]
+            return text
+        expanded = []
+        for subtext in text.split("\n\n"):
+            expanded.append(alter_it(subtext))
+        text = "\n\n".join(expanded)
+        return text
+
     def character_iter(cls, text):
         """Returns an iterator over the characters in text."""
         #We don't return more than one consecutive whitespace character
