@@ -31,6 +31,7 @@ try:
 except:
     import pickle
 from exceptions import NotImplementedError
+import translate.i18n
 from translate.storage.placeables.base import Placeable, as_string
 from translate.misc.typecheck import accepts, Self, IsOneOf
 from translate.misc.multistring import multistring
@@ -47,7 +48,11 @@ def force_override(method, baseclass):
         raise NotImplementedError("%s does not reimplement %s as required by %s" % (actualclass.__name__, method.__name__, baseclass.__name__))
 
 class ParseError(Exception):
-    pass
+    def __init__(self, inner_exc):
+        self.inner_exc = inner_exc
+
+    def __str__(self):
+        return repr(self.inner_exc)
 
 class TranslationUnit(object):
     """Base class for translation units.
@@ -82,7 +87,6 @@ class TranslationUnit(object):
         self.source = source
         self.target = None
         self.notes = ""
-        super(TranslationUnit, self).__init__()
 
     def __eq__(self, other):
         """Compares two TranslationUnits.
@@ -377,9 +381,6 @@ class TranslationStore(object):
         """Constructs a blank TranslationStore."""
 
         self.units = []
-        self.filepath = None
-        self.translator = ""
-        self.date = ""
         self.sourcelanguage = None
         self.targetlanguage = None
         if unitclass:
