@@ -152,8 +152,8 @@ def escapeforpo(text):
 def quoteforpo(text):
     return pypo.quoteforpo(text)
 
-def unquotefrompo(postr, joinwithlinebreak=False):
-    return pypo.unquotefrompo(postr, joinwithlinebreak)
+def unquotefrompo(postr):
+    return pypo.unquotefrompo(postr)
 
 def encodingToUse(encoding):
     return pypo.encodingToUse(encoding)
@@ -331,7 +331,7 @@ class pounit(pocommon.pounit):
 
     def addnote(self, text, origin=None, position="append"):
         # ignore empty strings and strings without non-space characters
-        if (not text) or (not text.strip()):
+        if not (text and text.strip()):
             return
         text = data.forceunicode(text)
         oldnotes = self.getnotes(origin)
@@ -527,9 +527,10 @@ class pofile(pocommon.pofile):
             self._gpo_memory_file = gpo.po_file_create()
             self._gpo_message_iterator = gpo.po_message_iterator(self._gpo_memory_file, None)
 
-    def addunit(self, unit):
-        gpo.po_message_insert(self._gpo_message_iterator, unit._gpo_message)
-        self.units.append(unit)
+    def addunit(self, unit, new=True):
+        if new:
+            gpo.po_message_insert(self._gpo_message_iterator, unit._gpo_message)
+        super(pofile, self).addunit(unit)
 
     def removeduplicates(self, duplicatestyle="merge"):
         """make sure each msgid is unique ; merge comments etc from duplicates into original"""
@@ -662,7 +663,7 @@ class pofile(pocommon.pofile):
         newmessage = gpo.po_next_message(self._gpo_message_iterator)
         while newmessage:
             newunit = pounit(gpo_message=newmessage)
-            self.units.append(newunit)
+            self.addunit(newunit, new=False)
             newmessage = gpo.po_next_message(self._gpo_message_iterator)
         self._free_iterator()
 
