@@ -26,7 +26,6 @@ from translate.storage import base
 from translate.misc import quote
 
 import re
-import sys
 import warnings
 try:
     from lxml import etree
@@ -34,6 +33,13 @@ try:
 except ImportError:
     etree = None
 
+labelsuffixes = (".label", ".title")
+"""Label suffixes: entries with this suffix are able to be comibed with accesskeys
+found in in entries ending with L{accesskeysuffixes}"""
+accesskeysuffixes = (".accesskey", ".accessKey", ".akey")
+"""Accesskey Suffixes: entries with this suffix may be combined with labels
+ending in L{labelsuffixes} into accelerator notation"""
+
 def quotefordtd(source):
     if '"' in source:
         if "'" in source:
@@ -46,7 +52,8 @@ def quotefordtd(source):
 def unquotefromdtd(source):
     """unquotes a quoted dtd definition"""
     # extract the string, get rid of quoting
-    if len(source) == 0: source = '""'
+    if len(source) == 0:
+        source = '""'
     quotechar = source[0]
     extracted, quotefinished = quote.extractwithoutquotes(source, quotechar, quotechar, allowreentry=False)
     if quotechar == "'" and "&apos;" in extracted:
@@ -55,6 +62,49 @@ def unquotefromdtd(source):
     # of course there could also be quote characters within the string; not handled here
     return extracted
 
+def removeinvalidamps(name, value):
+    """Find and remove ampersands that are not part of an entity definition.
+
+    A stray & in a DTD file can break an applications ability to parse the file.  In Mozilla
+    localisation this is very important and these can break the parsing of files used in XUL
+    and thus break interface rendering.  Tracking down the problem is very difficult,
+    thus by removing potential broken & and warning the users we can ensure that the output
+    DTD will always be parsable.
+
+    @type name: String
+    @param name: Entity name
+    @type value: String
+    @param value: Entity text value
+    @rtype: String
+    @return: Entity value without bad ampersands
+    """
+    def is_valid_entity_name(name):
+        """Check that supplied L{name} is a valid entity name"""
+        if name.replace('.', '').isalnum():
+            return True
+        elif name[0] == '#' and name[1:].isalnum():
+            return True
+        return False
+
+    amppos = 0
+    invalid_amps = []
+    while amppos >= 0:
+        amppos = value.find("&", amppos)
+        if amppos != -1:
+            amppos += 1
+            semipos = value.find(";", amppos)
+            if semipos != -1:
+                if is_valid_entity_name(value[amppos:semipos]):
+                    continue
+            invalid_amps.append(amppos-1)
+    if len(invalid_amps) > 0:
+        warnings.warn("invalid ampersands in dtd entity %s" % (name))
+        adjustment = 0
+        for amppos in invalid_amps:
+            value = value[:amppos-adjustment] + value[amppos-adjustment+1:]
+            adjustment += 1
+    return value
+
 class dtdunit(base.TranslationUnit):
     """this class represents an entity definition from a dtd file (and possibly associated comments)"""
     def __init__(self, source=""):
@@ -62,8 +112,8 @@ class dtdunit(base.TranslationUnit):
         super(dtdunit, self).__init__(source)
         self.comments = []
         self.unparsedlines = []
-        self.incomment = 0
-        self.inentity = 0
+        self.incomment = False
+        self.inentity = False
         self.entity = "FakeEntityOnlyForInitialisationAndTesting" 
         self.source = source
 
@@ -120,13 +170,14 @@ class dtdunit(base.TranslationUnit):
             # print "line(%d,%d): " % (self.incomment,self.inentity),line[:-1]
             if not self.incomment:
                 if (line.find('<!--') != -1):
-                    self.incomment = 1
-                    self.continuecomment = 0
+                    self.incomment = True
+                    self.continuecomment = False
                     # now work out the type of comment, and save it (remember we're not in the comment yet)
                     (comment, dummy) = quote.extract(line, "<!--", "-->", None, 0)
                     if comment.find('LOCALIZATION NOTE') != -1:
                         l = quote.findend(comment,'LOCALIZATION NOTE')
-                        while (comment[l] == ' '): l += 1
+                        while (comment[l] == ' '):
+                            l += 1
                         if comment.find('FILE', l) == l:
                             self.commenttype = "locfile"
                         elif comment.find('BEGIN', l) == l:
@@ -181,7 +232,7 @@ class dtdunit(base.TranslationUnit):
             if not self.inentity and not self.incomment:
                 entitypos = line.find('<!ENTITY')
                 if entitypos != -1:
-                    self.inentity = 1
+                    self.inentity = True
                     beforeentity = line[:entitypos].strip()
                     if beforeentity.startswith("#"):
                         self.hashprefix = beforeentity
@@ -198,17 +249,20 @@ class dtdunit(base.TranslationUnit):
                     self.entitytype = "internal"
                 if self.entitypart == "name":
                     e = 0
-                    while (e < len(line) and line[e].isspace()): e += 1
+                    while (e < len(line) and line[e].isspace()):
+                        e += 1
                     self.entity = ''
                     if (e < len(line) and line[e] == '%'):
                         self.entitytype = "external"
                         self.entityparameter = ""
                         e += 1
-                        while (e < len(line) and line[e].isspace()): e += 1
+                        while (e < len(line) and line[e].isspace()):
+                            e += 1
                     while (e < len(line) and not line[e].isspace()):
                         self.entity += line[e]
                         e += 1
-                    while (e < len(line) and line[e].isspace()): e += 1
+                    while (e < len(line) and line[e].isspace()):
+                        e += 1
                     if self.entity:
                         if self.entitytype == "external":
                             self.entitypart = "parameter"
@@ -217,15 +271,19 @@ class dtdunit(base.TranslationUnit):
                         # remember the start position and the quote character
                         if e == len(line):
                             self.entityhelp = None
+                            e = 0
                             continue
                         elif self.entitypart == "definition":
                             self.entityhelp = (e, line[e])
-                            self.instring = 0
+                            self.instring = False
                 if self.entitypart == "parameter":
-                    paramstart = e
-                    while (e < len(line) and line[e].isalnum()): e += 1
-                    self.entityparameter += line[paramstart:e]
                     while (e < len(line) and line[e].isspace()): e += 1
+                    paramstart = e
+                    while (e < len(line) and line[e].isalnum()):
+                        e += 1
+                    self.entityparameter += line[paramstart:e]
+                    while (e < len(line) and line[e].isspace()):
+                        e += 1
                     line = line[e:]
                     e = 0
                     if not line:
@@ -233,15 +291,16 @@ class dtdunit(base.TranslationUnit):
                     if line[0] in ('"', "'"):
                         self.entitypart = "definition"
                         self.entityhelp = (e, line[e])
-                        self.instring = 0
+                        self.instring = False
                 if self.entitypart == "definition":
                     if self.entityhelp is None:
                         e = 0
-                        while (e < len(line) and line[e].isspace()): e += 1
+                        while (e < len(line) and line[e].isspace()):
+                            e += 1
                         if e == len(line):
                             continue
                         self.entityhelp = (e, line[e])
-                        self.instring = 0
+                        self.instring = False
                     # actually the lines below should remember instring, rather than using it as dummy
                     e = self.entityhelp[0]
                     if (self.entityhelp[1] == "'"):
@@ -254,14 +313,15 @@ class dtdunit(base.TranslationUnit):
                     self.entityhelp = (0, self.entityhelp[1])
                     self.definition += defpart
                     if not self.instring:
-                        self.inentity = 0
+                        self.inentity = False
                         break
 
         # uncomment this line to debug processing
         if 0:
             for attr in dir(self):
                 r = repr(getattr(self, attr))
-                if len(r) > 60: r = r[:57]+"..."
+                if len(r) > 60:
+                    r = r[:57]+"..."
                 self.comments.append(("comment", "self.%s = %s" % (attr, r) ))
         return linesprocessed
 
@@ -302,7 +362,6 @@ class dtdfile(base.TranslationStore):
     def __init__(self, inputfile=None):
         """construct a dtdfile, optionally reading in from inputfile"""
         base.TranslationStore.__init__(self, unitclass = self.UnitClass)
-        self.units = []
         self.filename = getattr(inputfile, 'name', '')
         if inputfile is not None:
             dtdsrc = inputfile.read()
@@ -310,19 +369,19 @@ class dtdfile(base.TranslationStore):
             self.makeindex()
 
     def parse(self, dtdsrc):
-        """read the source code of a dtd file in and include them as dtdunits in self.units (any existing units are lost)"""
-        self.units = []
+        """read the source code of a dtd file in and include them as dtdunits in self.units"""
         start = 0
         end = 0
         lines = dtdsrc.split("\n")
         while end < len(lines):
-            if (start == end): end += 1
-            foundentity = 0
+            if (start == end):
+                end += 1
+            foundentity = False
             while end < len(lines):
                 if end >= len(lines):
                     break
                 if lines[end].find('<!ENTITY') > -1:
-                    foundentity = 1
+                    foundentity = True
                 if foundentity and re.match("[\"']\s*>", lines[end]):
                     end += 1
                     break
@@ -343,12 +402,9 @@ class dtdfile(base.TranslationStore):
     def __str__(self):
         """convert to a string. double check that unicode is handled somehow here"""
         source = self.getoutput()
-        if etree is not None:
-            try:
-                dtd = etree.DTD(StringIO.StringIO(re.sub("#expand", "", source)))
-            except etree.DTDParseError:
-                warnings.warn("DTD file '%s' does not validate" % self.filename)
-                return None
+        if not self._valid_store():
+            warnings.warn("DTD file '%s' does not validate" % self.filename)
+            return None
         if isinstance(source, unicode):
             return source.encode(getattr(self, "encoding", "UTF-8"))
         return source
@@ -365,21 +421,19 @@ class dtdfile(base.TranslationStore):
             if not dtd.isnull():
                 self.index[dtd.entity] = dtd
 
-    def rewrap(self):
-        for dtd in self.units:
-            lines = dtd.definition.split("\n")
-            if len(lines) > 1:
-                definition = lines[0]
-                for line in lines[1:]:
-                    if definition[-1:].isspace() or line[:1].isspace():
-                        definition += line
-                    else:
-                        definition += " " + line
-                dtd.definition = definition
+    def _valid_store(self):
+        """Validate the store to determine if it is valid
 
-if __name__ == "__main__":
-    import sys
-    d = dtdfile(sys.stdin)
-    d.rewrap()
-    sys.stdout.write(str(d))
+        This uses ElementTree to parse the DTD
+
+        @return: If the store passes validation
+        @rtype: Boolean
+        """ 
+        if etree is not None:
+            try:
+                # #expand is a Mozilla hack and are removed as they are not valid in DTDs
+                dtd = etree.DTD(StringIO.StringIO(re.sub("#expand", "", self.getoutput())))
+            except etree.DTDParseError:
+                return False
+        return True
 
