@@ -32,17 +32,11 @@ try:
 except ImportError, e:
     raise ImportError("lxml is not installed. It might be possible to continue without support for XML formats.")
 
+string_xpath = etree.XPath("string()")
+
 def getText(node):
     """joins together the text from all the text nodes in the nodelist and their children"""
-    # node.xpath is very slow, so we only use it if there are children
-    # TODO: consider rewriting by iterating over children
-    if node is not None:    # The etree way of testing for children
-        # Only non-ASCII strings are returned as unicode, so we have to force
-        # the ASCII-only ones to be unicode as well
-        return unicode(node.xpath("string()")) # specific to lxml.etree
-    else:
-        return data.forceunicode(node.text) or u""
-        # if node.text is none, we want to return "" since the tag is there
+    return unicode(string_xpath(node)) # specific to lxml.etree
 
 def _findAllMatches(text, re_obj):
     """generate match objects for all L{re_obj} matches in L{text}."""
@@ -105,13 +99,12 @@ Provisional work is done to make several languages possible."""
 
     namespace = None
 
-    def __init__(self, source, empty=False):
+    def __init__(self, source, empty=False, **kwargs):
         """Constructs a unit containing the given source string"""
         if empty:
             return
         self.xmlelement = etree.Element(self.rootNode)
         #add descrip, note, etc.
-
         super(LISAunit, self).__init__(source)
 
     def __eq__(self, other):
@@ -203,16 +196,28 @@ Provisional work is done to make several languages possible."""
     rich_target = property(get_rich_target, set_rich_target)
 
     def settarget(self, text, lang='xx', append=False):
-        #XXX: we really need the language - can't really be optional
+        #XXX: we really need the language - can't really be optional, and we
+        # need to propagate it
         """Sets the "target" string (second language), or alternatively appends to the list"""
         text = data.forceunicode(text)
         #Firstly deal with reinitialising to None or setting to identical string
         if self.gettarget() == text:
             return
-        languageNode = None
+        languageNode = self.get_target_dom(None)
         if not text is None:
-            languageNode = self.createlanguageNode(lang, text, "target")
-        self.set_target_dom(languageNode, append)
+            if languageNode is None:
+                languageNode = self.createlanguageNode(lang, text, "target")
+                self.set_target_dom(languageNode, append)
+            else:
+                if self.textNode:
+                    terms = languageNode.iter(self.namespaced(self.textNode))
+                    try:
+                        languageNode = terms.next()
+                    except StopIteration, e:
+                        pass
+                languageNode.text = text
+        else:
+            self.set_target_dom(None, False)
 
     def gettarget(self, lang=None):
         """retrieves the "target" text (second entry), or the entry in the 
@@ -256,7 +261,7 @@ Provisional work is done to make several languages possible."""
 
     def getlanguageNodes(self):
         """Returns a list of all nodes that contain per language information."""
-        return self.xmlelement.findall(self.namespaced(self.languageNode))
+        return list(self.xmlelement.iterchildren(self.namespaced(self.languageNode)))
 
     def getlanguageNode(self, lang=None, index=None):
         """Retrieves a languageNode either by language or by index"""
@@ -279,10 +284,11 @@ Provisional work is done to make several languages possible."""
         if languageNode is None:
             return None
         if self.textNode:
-            terms = languageNode.findall('.//%s' % self.namespaced(self.textNode))
-            if len(terms) == 0:
+            terms = languageNode.iterdescendants(self.namespaced(self.textNode))
+            if terms is None:
                 return None
-            return getText(terms[0])
+            else:
+                return getText(terms.next())
         else:
             return getText(languageNode)
 
@@ -328,6 +334,7 @@ class LISAfile(base.TranslationStore):
             # interfere with the the pretty printing of lxml
             self.parse(self.XMLskeleton.replace("\n", ""))
             self.addheader()
+        self._encoding = "UTF-8"
 
     def addheader(self):
         """Method to be overridden to initialise headers, etc."""
@@ -372,14 +379,17 @@ class LISAfile(base.TranslationStore):
             xml.seek(0)
             posrc = xml.read()
             xml = posrc
-        self.document = etree.fromstring(xml).getroottree()
-        self.encoding = self.document.docinfo.encoding
+        if etree.LXML_VERSION > (2, 1, 0):
+            #Since version 2.1.0 we can pass the strip_cdata parameter to 
+            #indicate that we don't want cdata to be converted to raw XML
+            parser = etree.XMLParser(strip_cdata=False)
+        else:
+            parser = etree.XMLParser()
+        self.document = etree.fromstring(xml, parser).getroottree()
+        self._encoding = self.document.docinfo.encoding
         self.initbody()
         assert self.document.getroot().tag == self.namespaced(self.rootNode)
-        termEntries = self.body.findall('.//%s' % self.namespaced(self.UnitClass.rootNode))
-        if termEntries is None:
-            return
-        for entry in termEntries:
+        for entry in self.body.iterdescendants(self.namespaced(self.UnitClass.rootNode)):
             term = self.UnitClass.createfromxmlElement(entry)
             self.addunit(term, new=False)
 
