@@ -37,7 +37,7 @@ def hasplurals(thing):
 
 class PoXliffUnit(xliff.xliffunit):
     """A class to specifically handle the plural units created from a po file."""
-    def __init__(self, source, empty=False):
+    def __init__(self, source=None, empty=False, encoding="UTF-8"):
         self.units = []
             
         if empty:
@@ -230,6 +230,9 @@ class PoXliffUnit(xliff.xliffunit):
     def isheader(self):
         return "gettext-domain-header" in (self.getrestype() or "")
 
+    def istranslatable(self):
+        return super(PoXliffUnit, self).istranslatable() and not self.isheader()
+
     def createfromxmlElement(cls, element, namespace=None):
         if element.tag.endswith("trans-unit"):
             object = cls(None, empty=True)
@@ -240,7 +243,7 @@ class PoXliffUnit(xliff.xliffunit):
         group = cls(None, empty=True)
         group.xmlelement = element
         group.namespace = namespace
-        units = element.findall('.//%s' % group.namespaced('trans-unit'))
+        units = list(element.iterdescendants(group.namespaced('trans-unit')))
         for unit in units:
             subunit = xliff.xliffunit.createfromxmlElement(unit)
             subunit.namespace = namespace
@@ -334,14 +337,15 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
             xml = xmlsrc
         self.document = etree.fromstring(xml).getroottree()
         self.initbody()
-        assert self.document.getroot().tag == self.namespaced(self.rootNode)
-        groups = self.document.findall(".//%s" % self.namespaced("group"))
+        root_node = self.document.getroot()
+        assert root_node.tag == self.namespaced(self.rootNode)
+        groups = root_node.iterdescendants(self.namespaced("group"))
         pluralgroups = filter(ispluralgroup, groups)
-        termEntries = self.body.findall('.//%s' % self.namespaced(self.UnitClass.rootNode))
-        if termEntries is None:
-            return
+        termEntries = root_node.iterdescendants(self.namespaced(self.UnitClass.rootNode))
 
         singularunits = filter(isnonpluralunit, termEntries)
+        if len(singularunits) == 0:
+            return
         pluralunit_iter = pluralunits(pluralgroups)
         try:
             nextplural = pluralunit_iter.next()
@@ -351,11 +355,11 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
         for entry in singularunits:
             term = self.UnitClass.createfromxmlElement(entry, namespace=self.namespace)
             if nextplural and unicode(term.source) in nextplural.source.strings:
-                self.units.append(nextplural)
+                self.addunit(nextplural, new=False)
                 try:
                     nextplural = pluralunit_iter.next()
                 except StopIteration, i:
                     nextplural = None
             else:
-                self.units.append(term)
+                self.addunit(term, new=False)
 
