@@ -29,6 +29,9 @@ from translate.misc import textwrap
 from translate.lang import data
 from translate.storage import pocommon, base
 import re
+import copy
+import cStringIO
+import poparser
 
 lsep = "\n#: "
 """Seperator for #: entries"""
@@ -86,6 +89,7 @@ def quoteforpo(text):
         if len(lines) != 2 or lines[1]:
             polines.extend(['""'])
         for line in lines[:-1]:
+            #TODO: We should only wrap after escaping
             lns = wrapline(line)
             if len(lns) > 0:
                 for ln in lns[:-1]:
@@ -122,18 +126,8 @@ def encodingToUse(encoding):
 #        return False
 #    return True
 
-"""
-From the GNU gettext manual:
-     WHITE-SPACE
-     #  TRANSLATOR-COMMENTS
-     #. AUTOMATIC-COMMENTS
-     #| PREVIOUS MSGID                 (Gettext 0.16 - check if this is the correct position - not yet implemented)
-     #: REFERENCE...
-     #, FLAG...
-     msgctxt CONTEXT                   (Gettext 0.15)
-     msgid UNTRANSLATED-STRING
-     msgstr TRANSLATED-STRING
-"""
+def is_null(lst):
+    return lst == [] or len(lst) == 1 and lst[0] == '""'
 
 def extractstr(string):
     left = string.find('"')
@@ -147,6 +141,9 @@ class pounit(pocommon.pounit):
     # othercomments = []      #   # this is another comment
     # automaticcomments = []  #   #. comment extracted from the source code
     # sourcecomments = []     #   #: sourcefile.xxx:35
+    # prev_msgctxt = []       #   #| The previous values that msgctxt and msgid held
+    # prev_msgid = []         # 
+    # prev_msgid_plural = []  # 
     # typecomments = []       #   #, fuzzy
     # msgidcomments = []      #   _: within msgid
     # msgctxt
@@ -157,6 +154,9 @@ class pounit(pocommon.pounit):
         self._encoding = encodingToUse(encoding)
         self.obsolete = False
         self._initallcomments(blankall=True)
+        self.prev_msgctxt = []
+        self.prev_msgid = []
+        self.prev_msgid_plural = []
         self.msgctxt = []
         self.msgid = []
         self.msgid_pluralcomments = []
@@ -167,9 +167,7 @@ class pounit(pocommon.pounit):
         self.obsoletemsgid_pluralcomments = []
         self.obsoletemsgid_plural = []
         self.obsoletemsgstr = []
-        if source:
-            self.setsource(source)
-        super(pounit, self).__init__(source)
+        pocommon.pounit.__init__(self, source)
 
     def _initallcomments(self, blankall=False):
         """Initialises allcomments"""
@@ -180,40 +178,68 @@ class pounit(pocommon.pounit):
             self.typecomments = []
             self.msgidcomments = []
             self.obsoletemsgidcomments = []
-        self.allcomments = [self.othercomments, 
-                            self.automaticcomments, 
-                            self.sourcecomments, 
-                            self.typecomments, 
-                            self.msgidcomments,
-                            self.obsoletemsgidcomments]
 
-    def getsource(self):
-        """Returns the unescaped msgid"""
-        multi = multistring(unquotefrompo(self.msgid), self._encoding)
+    def _get_all_comments(self):
+        return [self.othercomments, 
+                self.automaticcomments, 
+                self.sourcecomments, 
+                self.typecomments, 
+                self.msgidcomments,
+                self.obsoletemsgidcomments]
+
+    allcomments = property(_get_all_comments)
+
+    def _get_source_vars(self, msgid, msgid_plural):
+        multi = multistring(unquotefrompo(msgid), self._encoding)
         if self.hasplural():
-            pluralform = unquotefrompo(self.msgid_plural)
+            pluralform = unquotefrompo(msgid_plural)
             if isinstance(pluralform, str):
                 pluralform = pluralform.decode(self._encoding)
             multi.strings.append(pluralform)
         return multi
 
+    def _set_source_vars(self, source):
+        msgid = None
+        msgid_plural = None
+        if isinstance(source, str):
+            source = source.decode(self._encoding)
+        if isinstance(source, multistring):
+            source = source.strings
+        if isinstance(source, list):
+            msgid = quoteforpo(source[0])
+            if len(source) > 1:
+                msgid_plural = quoteforpo(source[1])
+            else:
+                msgid_plural = []
+        else:
+            msgid = quoteforpo(source)
+            msgid_plural = []
+        return msgid, msgid_plural
+
+    def getsource(self):
+        """Returns the unescaped msgid"""
+        return self._get_source_vars(self.msgid, self.msgid_plural)
+
     def setsource(self, source):
         """Sets the msgid to the given (unescaped) value.
         
         @param source: an unescaped source string.
         """
-        if isinstance(source, str):
-            source = source.decode(self._encoding)
-        if isinstance(source, multistring):
-            source = source.strings
-        if isinstance(source, list):
-            self.msgid = quoteforpo(source[0])
-            if len(source) > 1:
-                self.msgid_plural = quoteforpo(source[1])
-        else:
-            self.msgid = quoteforpo(source)
+        self.msgid, self.msgid_plural = self._set_source_vars(source)
     source = property(getsource, setsource)
 
+    def _get_prev_source(self):
+        """Returns the unescaped msgid"""
+        return self._get_source_vars(self.prev_msgid, self.prev_msgid_plural)
+
+    def _set_prev_source(self, source):
+        """Sets the msgid to the given (unescaped) value.
+        
+        @param source: an unescaped source string.
+        """
+        self.prev_msgid, self.prev_msgid_plural = self._set_source_vars(source)
+    prev_source = property(_get_prev_source, _set_prev_source)
+
     def gettarget(self):
         """Returns the unescaped msgstr"""
         if isinstance(self.msgstr, dict):
@@ -226,8 +252,6 @@ class pounit(pocommon.pounit):
         """Sets the msgstr to the given (unescaped) value"""
         if isinstance(target, str):
             target = target.decode(self._encoding)
-        if target == self.target:
-            return
         if self.hasplural():
             if isinstance(target, multistring):
                 target = target.strings
@@ -265,8 +289,8 @@ class pounit(pocommon.pounit):
 
     def addnote(self, text, origin=None, position="append"):
         """This is modeled on the XLIFF method. See xliff.py::xliffunit.addnote"""
-        # We don't want to put in an empty '#' without a real comment:
-        if not text:
+        # ignore empty strings and strings without non-space characters
+        if not (text and text.strip()):
             return
         text = data.forceunicode(text)
         commentlist = self.othercomments
@@ -291,40 +315,15 @@ class pounit(pocommon.pounit):
         self.othercomments = []
 
     def copy(self):
-        newpo = self.__class__()
-        newpo.othercomments = self.othercomments[:]
-        newpo.automaticcomments = self.automaticcomments[:]
-        newpo.sourcecomments = self.sourcecomments[:]
-        newpo.typecomments = self.typecomments[:]
-        newpo.obsolete = self.obsolete
-        newpo.msgidcomments = self.msgidcomments[:]
-        newpo._initallcomments()
-        newpo.msgctxt = self.msgctxt[:]
-        newpo.msgid = self.msgid[:]
-        newpo.msgid_pluralcomments = self.msgid_pluralcomments[:]
-        newpo.msgid_plural = self.msgid_plural[:]
-        if isinstance(self.msgstr, dict):
-            newpo.msgstr = self.msgstr.copy()
-        else:
-            newpo.msgstr = self.msgstr[:]
-            
-        newpo.obsoletemsgctxt = self.obsoletemsgctxt[:]
-        newpo.obsoletemsgid = self.obsoletemsgid[:]
-        newpo.obsoletemsgid_pluralcomments = self.obsoletemsgid_pluralcomments[:]
-        newpo.obsoletemsgid_plural = self.obsoletemsgid_plural[:]
-        if isinstance(self.obsoletemsgstr, dict):
-            newpo.obsoletemsgstr = self.obsoletemsgstr.copy()
-        else:
-            newpo.obsoletemsgstr = self.obsoletemsgstr[:]
-        return newpo
+        return copy.deepcopy(self)
 
-    def msgidlen(self):
+    def _msgidlen(self):
         if self.hasplural():
             return len(unquotefrompo(self.msgid).strip()) + len(unquotefrompo(self.msgid_plural).strip())
         else:
             return len(unquotefrompo(self.msgid).strip())
 
-    def msgstrlen(self):
+    def _msgstrlen(self):
         if isinstance(self.msgstr, dict):
             combinedstr = "\n".join([unquotefrompo(msgstr).strip() for msgstr in self.msgstr.itervalues()])
             return len(combinedstr.strip())
@@ -410,18 +409,18 @@ class pounit(pocommon.pounit):
                 self.markfuzzy()
 
     def isheader(self):
-        #return (self.msgidlen() == 0) and (self.msgstrlen() > 0) and (len(self.msgidcomments) == 0)
-        #rewritten here for performance:
-        return ((self.msgid == [] or self.msgid == ['""']) and 
-                        not (self.msgstr == [] or self.msgstr == ['""']) 
+        #return (self._msgidlen() == 0) and (self._msgstrlen() > 0) and (len(self.msgidcomments) == 0)
+        #rewritten here for performance:        
+        return (is_null(self.msgid) 
+                        and not is_null(self.msgstr) 
                         and self.msgidcomments == []
-                        and (self.msgctxt == [] or self.msgctxt == ['""'])
-                        and (self.sourcecomments == [] or self.sourcecomments == [""]))
+                        and is_null(self.msgctxt)
+        )
 
     def isblank(self):
         if self.isheader() or len(self.msgidcomments):
             return False
-        if (self.msgidlen() == 0) and (self.msgstrlen() == 0):
+        if (self._msgidlen() == 0) and (self._msgstrlen() == 0):
             return True
         return False
         # TODO: remove:
@@ -512,112 +511,8 @@ class pounit(pocommon.pounit):
         """returns whether this pounit contains plural strings..."""
         return len(self.msgid_plural) > 0
 
-    def parselines(self, lines):
-        inmsgctxt = 0
-        inmsgid = 0
-        inmsgid_comment = 0
-        inmsgid_plural = 0
-        inmsgstr = 0
-        msgstr_pluralid = None
-        linesprocessed = 0
-        for line in lines:
-            line = line + "\n"
-            linesprocessed += 1
-            if len(line) == 0:
-                continue
-            elif line[0] == '#':
-                if inmsgstr and not line[1] == '~':
-                    # if we're already in the message string, this is from the next element
-                    break
-                if line[1] == '.':
-                    self.automaticcomments.append(line)
-                elif line[1] == ':':
-                    self.sourcecomments.append(line)
-                elif line[1] == ',':
-                    self.typecomments.append(line)
-                elif line[1] == '~':
-                    line = line[3:]
-                    self.obsolete = True
-                else:
-                    self.othercomments.append(line)
-            if line.startswith('msgid_plural'):
-                inmsgctxt = 0
-                inmsgid = 0
-                inmsgid_plural = 1
-                inmsgstr = 0
-                inmsgid_comment = 0
-            elif line.startswith('msgctxt'):
-                inmsgctxt = 1
-                inmsgid = 0
-                inmsgid_plural = 0
-                inmsgstr = 0
-                inmsgid_comment = 0
-            elif line.startswith('msgid'):
-                # if we just finished a msgstr or msgid_plural, there is probably an 
-                # empty line missing between the units, so let's stop the parsing now.
-                if inmsgstr or inmsgid_plural:
-                    break
-                inmsgctxt = 0
-                inmsgid = 1
-                inmsgid_plural = 0
-                inmsgstr = 0
-                inmsgid_comment = 0
-            elif line.startswith('msgstr'):
-                inmsgctxt = 0
-                inmsgid = 0
-                inmsgid_plural = 0
-                inmsgstr = 1
-                if line.startswith('msgstr['):
-                    msgstr_pluralid = int(line[len('msgstr['):line.find(']')].strip())
-                else:
-                    msgstr_pluralid = None
-            extracted = extractstr(line)
-            if not extracted is None:
-                if inmsgctxt:
-                    self.msgctxt.append(extracted)
-                elif inmsgid:
-                    # TODO: improve kde comment detection
-                    if extracted.find("_:") != -1:
-                        inmsgid_comment = 1
-                    if inmsgid_comment:
-                        self.msgidcomments.append(extracted)
-                    else:
-                        self.msgid.append(extracted)
-                    if inmsgid_comment and extracted.find("\\n") != -1:
-                        inmsgid_comment = 0
-                elif inmsgid_plural:
-                    if extracted.find("_:") != -1:
-                        inmsgid_comment = 1
-                    if inmsgid_comment:
-                        self.msgid_pluralcomments.append(extracted)
-                    else:
-                        self.msgid_plural.append(extracted)
-                    if inmsgid_comment and extracted.find("\\n") != -1:
-                        inmsgid_comment = 0
-                elif inmsgstr:
-                    if msgstr_pluralid is None:
-                        self.msgstr.append(extracted)
-                    else:
-                        if type(self.msgstr) == list:
-                            self.msgstr = {0: self.msgstr}
-                        if msgstr_pluralid not in self.msgstr:
-                            self.msgstr[msgstr_pluralid] = []
-                        self.msgstr[msgstr_pluralid].append(extracted)
-        if self.obsolete:
-            self.makeobsolete()
-        # If this unit is the header, we have to get the encoding to ensure that no
-        # methods are called that need the encoding before we obtained it.
-        if self.isheader():
-            charset = re.search("charset=([^\\s]+)", unquotefrompo(self.msgstr))
-            if charset:
-                self._encoding = encodingToUse(charset.group(1))
-        return linesprocessed
-
     def parse(self, src):
-        if isinstance(src, str):
-            # This has not been decoded yet, so we need to make a plan
-            src = src.decode(self._encoding)
-        return self.parselines(src.split("\n"))
+        return poparser.parse_unit(poparser.ParseState(cStringIO.StringIO(src), pounit), self)
 
     def _getmsgpartstr(self, partname, partlines, partcomments=""):
         if isinstance(partlines, dict):
@@ -676,6 +571,16 @@ class pounit(pocommon.pounit):
 
     def _getoutput(self):
         """return this po element as a string"""
+        def add_prev_msgid_lines(lines, header, var):
+            if len(var) > 0:
+                lines.append("#| %s %s\n" % (header, var[0]))
+                lines.extend("#| %s\n" % line for line in var[1:])
+
+        def add_prev_msgid_info(lines):
+            add_prev_msgid_lines(lines, 'msgctxt', self.prev_msgctxt)
+            add_prev_msgid_lines(lines, 'msgid', self.prev_msgid)
+            add_prev_msgid_lines(lines, 'msgid_plural', self.prev_msgid_plural)
+
         lines = []
         lines.extend(self.othercomments)
         if self.isobsolete():
@@ -695,11 +600,12 @@ class pounit(pocommon.pounit):
             return "".join(lines)
         # if there's no msgid don't do msgid and string, unless we're the header
         # this will also discard any comments other than plain othercomments...
-        if (len(self.msgid) == 0) or ((len(self.msgid) == 1) and (self.msgid[0] == '""')):
+        if is_null(self.msgid):
             if not (self.isheader() or self.msgidcomments or self.sourcecomments):
                 return "".join(lines)
         lines.extend(self.automaticcomments)
         lines.extend(self.sourcecomments)
+        add_prev_msgid_info(lines)
         lines.extend(self.typecomments)
         if self.msgctxt:
             lines.append(self._getmsgpartstr("msgctxt", self.msgctxt))
@@ -814,45 +720,11 @@ class pofile(pocommon.pofile):
                 self.filename = input.name
             elif not getattr(self, 'filename', ''):
                 self.filename = ''
-            if hasattr(input, "read"):
-                posrc = input.read()
-                input.close()
-                input = posrc
-            # TODO: change this to a proper parser that doesn't do line-by-line madness
-            lines = input.split("\n")
-            start = 0
-            end = 0
-            # make only the first one the header
-            linesprocessed = 0
-            is_decoded = False
-            while end <= len(lines):
-                if (end == len(lines)) or (not lines[end].strip()):  # end of lines or blank line
-                    newpe = self.UnitClass(encoding=self._encoding)
-                    unit_lines = lines[start:end]
-                    # We need to work carefully if we haven't decoded properly yet.
-                    # So let's solve this temporarily until we actually get the
-                    # encoding from the header.
-                    if not is_decoded:
-                        unit_lines = [line.decode('ascii', 'ignore') for line in unit_lines]
-                    linesprocessed = newpe.parselines(unit_lines)
-                    start += linesprocessed
-                    # TODO: find a better way of working out if we actually read anything
-                    if linesprocessed >= 1 and newpe._getoutput():
-                        self.units.append(newpe)
-                        if not is_decoded:
-                            if newpe.isheader(): # If there is a header...
-                                if "Content-Type" in self.parseheader(): # and a Content-Type...
-                                    if self._encoding.lower() != 'charset': # with a valid charset...
-                                        self._encoding = newpe._encoding # then change the encoding
-                                        # otherwise we'll decode using UTF-8
-                            lines = self.decode(lines)
-                            self.units = []
-                            start = 0
-                            end = 0
-                            is_decoded = True
-                end = end+1
+            if isinstance(input, str):
+                input = cStringIO.StringIO(input)
+            poparser.parse_units(poparser.ParseState(input, pounit), self)
         except Exception, e:
-            raise base.ParseError()
+            raise base.ParseError(e)
 
     def removeduplicates(self, duplicatestyle="merge"):
         """make sure each msgid is unique ; merge comments etc from duplicates into original"""
@@ -869,7 +741,7 @@ class pofile(pocommon.pofile):
                 msgid = unquotefrompo(thepo.msgidcomments) + unquotefrompo(thepo.msgid)
             else:
                 msgid = unquotefrompo(thepo.msgid)
-            if thepo.isheader():
+            if thepo.isheader() and not thepo.getlocations():
                 # header msgids shouldn't be merged...
                 uniqueunits.append(thepo)
             elif duplicatestyle == "msgid_comment_all":
@@ -951,8 +823,3 @@ class pofile(pocommon.pofile):
             if not (unit.isheader() or unit.isobsolete()):
                 yield unit
 
-if __name__ == '__main__':
-    import sys
-    pf = pofile(sys.stdin)
-    sys.stdout.write(str(pf))
-
