@@ -62,6 +62,7 @@ class qmunit(base.TranslationUnit):
 class qmfile(base.TranslationStore):
     """A class representing a .qm file."""
     UnitClass = qmunit
+    Name = _("Qt .qm file")
     Mimetypes  = ["application/x-qm"]
     Extensions = ["qm"]
     _binary = True
@@ -167,3 +168,6 @@ class qmfile(base.TranslationStore):
                     subsection_name = "Unkown"
                 print >> sys.stderr, "Unimplemented: %s %s" % (subsection, subsection_name)
                 return
+
+    def savefile(self, storefile):
+        raise Exception("Writing of .qm files is not supported yet")
