@@ -3,6 +3,8 @@
 from translate.storage import dtd
 from translate.storage import test_monolingual
 from translate.misc import wStringIO
+import warnings
+from py import test
 
 def test_roundtrip_quoting():
     specials = ['Fish & chips', 'five < six', 'six > five',
@@ -17,6 +19,18 @@ def test_roundtrip_quoting():
         print "special: %r\nquoted: %r\nunquoted: %r\n" % (special, quoted_special, unquoted_special)
         assert special == unquoted_special
 
+def test_removeinvalidamp():
+    """tests the the removeinvalidamps function"""
+    def tester(actual, expected):
+        assert dtd.removeinvalidamps("test.name", actual) == expected
+    tester("Valid &entity; included", "Valid &entity; included")
+    tester("Valid &entity.name; included", "Valid &entity.name; included")
+    tester("Valid &#1234; included", "Valid &#1234; included")
+    tester("This &amp is broken", "This amp is broken")
+    tester("Mad & &amp &amp;", "Mad  amp &amp;")
+    warnings.simplefilter("error")
+    assert test.raises(Warning, dtd.removeinvalidamps, "simple.warningtest", "Dimpled &Ring")
+
 class TestDTDUnit(test_monolingual.TestMonolingualUnit):
     UnitClass = dtd.dtdunit
 
@@ -110,6 +124,25 @@ class TestDTD(test_monolingual.TestMonolingualStore):
         """checks that an &entity; in the source is retained"""
         dtdsource = '<!ENTITY % realBrandDTD SYSTEM "chrome://branding/locale/brand.dtd">\n%realBrandDTD;\n'
         dtdregen = self.dtdregen(dtdsource)
+        assert dtdsource == dtdregen
+
+    #test for bug #610
+    def test_entitityreference_order_in_source(self):
+        """checks that an &entity; in the source is retained"""
+        dtdsource = '<!ENTITY % realBrandDTD SYSTEM "chrome://branding/locale/brand.dtd">\n%realBrandDTD;\n<!-- some comment -->\n'
+        dtdregen = self.dtdregen(dtdsource)
+        assert dtdsource == dtdregen
+
+        # The following test is identical to the one above, except that the entity is split over two lines.
+        # This is to ensure that a recent bug fixed in dtdunit.parse() is at least partly documented.
+        # The essence of the bug was that after it had read "realBrandDTD", the line index is not reset
+        # before starting to parse the next line. It would then read the next available word (sequence of
+        # alphanum characters) in stead of SYSTEM and then get very confused by not finding an opening ' or
+        # " in the entity, borking the parsing for threst of the file.
+        dtdsource = '<!ENTITY % realBrandDTD\n SYSTEM "chrome://branding/locale/brand.dtd">\n%realBrandDTD;\n'
+        # FIXME: The following line is necessary, because of dtdfile's inability to remember the spacing of
+        # the source DTD file when converting back to DTD.
+        dtdregen = self.dtdregen(dtdsource).replace('realBrandDTD SYSTEM', 'realBrandDTD\n SYSTEM')
         print dtdsource
         print dtdregen
         assert dtdsource == dtdregen
@@ -140,7 +173,8 @@ class TestDTD(test_monolingual.TestMonolingualStore):
     def test_missing_quotes(self):
         """test that we fail graacefully when a message without quotes is found (bug #161)"""
         dtdsource = '<!ENTITY bad no quotes">\n<!ENTITY good "correct quotes">\n'
+        warnings.simplefilter("error")
+        assert test.raises(Warning, self.dtdparse, dtdsource)
+        warnings.resetwarnings()
         dtdfile = self.dtdparse(dtdsource)
-        # Check that we raise a correct warning
         assert len(dtdfile.units) == 1
-
