@@ -364,6 +364,25 @@ msgstr "tweede"
         assert unit.isobsolete()
         assert str(pofile) == posource
 
+        posource = '''msgid "one"
+msgstr "een"
+
+#, fuzzy
+#~ msgid "File not found."
+#~ msgid_plural "Files not found."
+#~ msgstr[0] "Leer(s) nie gevind nie."
+#~ msgstr[1] "Leer(s) nie gevind nie."
+'''
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 2
+        unit = pofile.units[1]
+        assert unit.isobsolete()
+
+        assert str(pofile) == posource
+        unit.resurrect()
+        assert unit.hasplural()
+
+
     def test_header_escapes(self):
         pofile = self.StoreClass()
         header = pofile.makeheader(**{"Report-Msgid-Bugs-To": r"http://qa.openoffice.org/issues/enter_bug.cgi?subcomponent=ui&comment=&short_desc=Localization%20issue%20in%20file%3A%20dbaccess\source\core\resource.oo&component=l10n&form_name=enter_issue"})
@@ -439,7 +458,7 @@ msgstr[1] "Koeie"
 
     def test_multiline_obsolete(self):
         """Tests for correct output of mulitline obsolete messages"""
-        posource = '#~ msgid "Old thing\\n"\n#~ "Second old thing"\n#~ msgstr "Ou ding\\n"\n#~ "Tweede ou ding"\n'
+        posource = '#~ msgid ""\n#~ "Old thing\\n"\n#~ "Second old thing"\n#~ msgstr ""\n#~ "Ou ding\\n"\n#~ "Tweede ou ding"\n'
         pofile = self.poparse(posource)
         assert pofile.isempty()
         assert len(pofile.units) == 1
@@ -564,6 +583,15 @@ msgstr "omskakel"
         unit = pofile.units[1]
         assert unit.getcontext() == 'Verb. _: The action of changing.'
         assert unit.getnotes() == 'Test comment 2'
+
+    def test_broken_kde_context(self):
+        posource = '''msgid "Broken _: here"
+msgstr "Broken _: here"
+'''
+        pofile = self.poparse(posource)
+        unit = pofile.units[0]
+        assert unit.source == "Broken _: here"
+        assert unit.target == "Broken _: here"
   
     def test_id(self):
         """checks that ids work correctly"""
@@ -603,3 +631,22 @@ msgstr[0] ""
         # commented out for conformance to gettext.
 #        assert pofile.units[4].getid() == "tree\0trees"
 
+    def test_non_ascii_header_comments(self):
+        posource = r'''
+# Tëśt þis.
+# Hé Há Hó.
+#. Lêkkør.
+msgid ""
+msgstr ""
+"PO-Revision-Date: 2006-02-09 23:33+0200\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8-bit\n"
+
+msgid "a"
+msgstr "b"
+'''        
+        pofile = self.poparse(posource)
+        for line in pofile.units[0].getnotes():
+            assert isinstance(line, unicode)
+        
