@@ -48,7 +48,7 @@ class TestPYPOUnit(test_po.TestPOUnit):
         unit.target = "Boom"
         # FIXME: currently assigning the target to the same as the first string won't change anything
         # we need to verify that this is the desired behaviour...
-        assert unit.target.strings == ["Boom", "Bome"]
+        assert unit.target.strings == ["Boom"]
         unit.target = "Een Boom"
         assert unit.target.strings == ["Een Boom"]
 
@@ -236,7 +236,57 @@ class TestPYPOFile(test_po.TestPOFile):
         """tests behaviour of unassociated comments."""
         oldsource = '# old lonesome comment\n\nmsgid "one"\nmsgstr "een"\n'
         oldfile = self.poparse(oldsource)
-        print "__str__", str(oldfile)
-        assert len(oldfile.units) == 2
-        assert str(oldfile).find("# old lonesome comment\n\n") >= 0
-    
+        print str(oldfile)
+        assert len(oldfile.units) == 1
+
+    def test_prevmsgid_parse(self):
+        """checks that prevmsgid (i.e. #|) is parsed and saved correctly"""
+        posource = r'''msgid ""
+msgstr ""
+"PO-Revision-Date: 2006-02-09 23:33+0200\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8-bit\n"
+
+#| msgid "trea"
+msgid "tree"
+msgstr "boom"
+
+#| msgid "trea"
+#| msgid_plural "treas"
+msgid "tree"
+msgid_plural "trees"
+msgstr[0] "boom"
+msgstr[1] "bome"
+
+#| msgctxt "context 1"
+#| msgid "tast"
+msgctxt "context 1a"
+msgid "test"
+msgstr "toets"
+
+#| msgctxt "context 2"
+#| msgid "tast"
+#| msgid_plural "tasts"
+msgctxt "context 2a"
+msgid "test"
+msgid_plural "tests"
+msgstr[0] "toet"
+msgstr[1] "toetse"
+'''
+
+        pofile = self.poparse(posource)
+
+        assert pofile.units[1].prev_msgctxt == []
+        assert pofile.units[1].prev_source == multistring([u"trea"])
+
+        assert pofile.units[2].prev_msgctxt == []
+        assert pofile.units[2].prev_source == multistring([u"trea", u"treas"])
+
+        assert pofile.units[3].prev_msgctxt == [u'"context 1"']
+        assert pofile.units[3].prev_source == multistring([u"tast"])
+
+        assert pofile.units[4].prev_msgctxt == [u'"context 2"']
+        assert pofile.units[4].prev_source == multistring([u"tast", u"tasts"])
+
+        assert str(pofile) == posource
