@@ -24,7 +24,7 @@ class TestWFUnit(test_base.TestTranslationUnit):
     UnitClass = wf.WordfastUnit
 
     def test_difficult_escapes(self):
-        """Wordfast files need to perform magic with escapes.
+        r"""Wordfast files need to perform magic with escapes.
         
            Wordfast does not accept line breaks in its TM (even though they would be
            valid in CSV) thus we turn \\n into \n and reimplement the base class test but
