@@ -90,6 +90,7 @@
 """
 
 import csv
+import sys
 import time
 from translate.storage import base
 
@@ -186,10 +187,14 @@ class WordfastDialect(csv.Dialect):
     delimiter = "\t"
     lineterminator = "\r\n"
     quoting = csv.QUOTE_NONE
-    # We need to define the following 3 items for csv in Python < 2.5
-    doublequote = False
-    skipinitialspace = False
-    escapechar = ''
+    if sys.version_info < (2, 5, 0):
+        # We need to define the following items for csv in Python < 2.5
+        quoting = csv.QUOTE_MINIMAL   # Wordfast does not quote anything, since we escape
+                                      # \t anyway in _char_to_wf this should not be a problem
+        doublequote = False
+        skipinitialspace = False
+        escapechar = None
+        quotechar ='"'
 csv.register_dialect("wordfast", WordfastDialect)
 
 class WordfastTime(object):
@@ -345,7 +350,7 @@ class WordfastUnit(base.TranslationUnit):
 
 class WordfastTMFile(base.TranslationStore):
     """A Wordfast translation memory file"""
-    Name = "Wordfast TM file"
+    Name = _("Wordfast TM file")
     Mimetypes  = ["application/x-wordfast"]
     Extensions = ["txt"]
     def __init__(self, inputfile=None, unitclass=WordfastUnit):
@@ -354,7 +359,7 @@ class WordfastTMFile(base.TranslationStore):
         base.TranslationStore.__init__(self, unitclass=unitclass)
         self.filename = ''
         self.header = WordfastHeader()
-        self._encoding = 'utf-16'
+        self._encoding = 'iso-8859-1'
         if inputfile is not None:
             self.parse(inputfile)
 
